### Get Pop

Command line tool that generates CSVs of population data for specified US states.

#### Install

```pip install get-pop```

#### Basic usage

To generate CSVs for specific states, use the 'getpop' command followed by the two letter postal code abbreviation
 for one or more states.
 
 CSVs will be output in the current working directory in a directory named 'data'.
 
 Example 1:
 
 ```getpop ny```
 
  Example 2:
  
  ```getpop ny nj tx pa```